@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from os import PathLike
 from pathlib import Path
-from typing import BinaryIO, Optional
+from typing import IO, Optional
 
 from aiofiles import open as async_open
 from werkzeug.datastructures import FileStorage as WerkzeugFileStorage, Headers
@@ -13,7 +13,7 @@ class FileStorage(WerkzeugFileStorage):
 
     def __init__(
         self,
-        stream: Optional[BinaryIO] = None,
+        stream: Optional[IO[bytes]] = None,
         filename: Optional[str] = None,
         name: Optional[str] = None,
         content_type: Optional[str] = None,
