@@ -3,7 +3,7 @@ from __future__ import annotations
 from functools import wraps
 from typing import Any, Callable, List, Optional, Tuple
 
-from blinker import NamedSignal, Namespace
+from blinker import NamedSignal, Namespace  # type: ignore[import]
 
 from .utils import is_coroutine_function
 
@@ -70,6 +70,15 @@ request_finished = _signals.signal("request-finished")
 # should have a signature of Callable[[Quart, Exception], None]
 request_tearing_down = _signals.signal("request-tearing-down")
 
+#: Called if there is an exception in a background task, connected
+# functions should have a signature of Callable[[Quart, Exception], None]
+got_background_exception = _signals.signal("got-background-exception")
+
+#: Called if there is an exception in a before or after serving
+# function, connected functions should have a signature of
+# Callable[[Quart, Exception], None]
+got_serving_exception = _signals.signal("got-serving-exception")
+
 #: Called if there is an exception handling the request, connected
 # functions should have a signature of Callable[[Quart, Exception], None]
 got_request_exception = _signals.signal("got-request-exception")
@@ -106,7 +115,7 @@ appcontext_tearing_down = _signals.signal("appcontext-tearing-down")
 # have a signature of Callable[[Quart], None]
 appcontext_pushed = _signals.signal("appcontext-pushed")
 
-#: Called when the app context is poped, connected functions should
+#: Called when the app context is popped, connected functions should
 # have a signature of Callable[[Quart], None]
 appcontext_popped = _signals.signal("appcontext-popped")
 
